# StartBlobUploadRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **object** | The type of the blob (one of \&quot;dataset\&quot;, \&quot;model\&quot;, \&quot;inbox\&quot;) | [optional] 
**name** | **str** | Name of the file | 
**content_length** | **int** | Content length of the file in bytes | 
**content_type** | **str** | Content/MIME type (e.g. \&quot;text/plain\&quot;) of the file | [optional] 
**last_modified_epoch_seconds** | **int** | Last modified date of file in seconds since epoch in UTC | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


